@@ -9,4 +9,7 @@ url = 0
 port = 5001
 video_que = Queue(maxsize=1)
 video_from_url_que = Queue(maxsize=1)
+hik_ip = '192.168.1.64'
+hik_password = 'Asb11023'
+hik_username = 'admin'
 
